
function [crit,b1]=estTurnoverCrit2(b) 


global r k tau T N M draw alpha burn b0
global B 
% global nu mu s phi rho sig

logit=@(x) 1/(1+exp(x));

nu=exp(b(1));
mu=exp(b(2)); 
s=logit(b(3));
phi=logit(b(4));
rho=tanh(b(5));
sig=exp(b(6));
z0=exp(b(7));
C=exp(b(8));

% grid for abilities
trim=.002;
x=linspace(trim,1-trim,M)';
l=betapdf(x,nu,mu);
l=l/sum(l);


% grid for productivity
F = linspace(trim,1-trim,N)';
y = exp(sig*norminv(F));
% fy = normpdf(log(y),0,sig)./y; fy=fy/sum(fy);
[U1,U2] = meshgrid(F); 
P = copulapdf('Gaussian',[U1(:) U2(:)],rho); 
P = reshape(P,N,N);
Pi = P./repmat(sum(P,2),1,N);


% match productivity
p=y*(B*x+C)';

 
% unemployment payoff
z=z0+alpha*(p-z0);



%% Unemployment value and surplus

beta=(1-s)/(1+r);

% p and z are NxM matrices 
% U and S also
Ux = (eye(N)-Pi/(1+r))\z;
Sx = (eye(N)-beta*Pi)\(p-z);
e = norm(Sx-max(Sx,0),'fro');

while e>0.0001
    Sx1 = Sx;
    Sx = p-z + beta*Pi*max(Sx,0);
    e=norm(Sx-Sx1,'fro');
end

S = max(Sx,0)*l; % aggregate surplus
L = (Sx>0)*l;

%% Interpolation

% fSx = Sx([1:N N-1:-1:2],:);
% fSx = real(fft(fSx/2/(N-1)));
% fSx = [fSx(1,:); fSx(2:(N-1),:)+fSx(2*(N-1):-1:N+1,:); fSx(N,:)];
% f_Sx = @(F) cos( acos( (-2*F+(Fmin+Fmax))/(Fmax-Fmin) )*(0:N-1))*fSx(1:N,:);
% f_Sx = @(Ft) interp1(F,Sx,Ft,'spline');

%% Steady-state

ux = (s/(s+phi))*(Sx>0)+(Sx<=0);
u = 1-phi.*L./(s+phi);


%% Dynamics

%initial conditionrn
i = round(N/2);
yt = y(i)*ones(T+burn,1);
uxt = repmat(ux(i,:),T+burn+1,1);
Sxt = repmat(Sx(i,:),T+burn+1,1);

for t=1:T+burn
    i=min(1+sum(draw(t)>cumsum(Pi(i,:))),N);
    yt(t) = y(i);    
    Sxt(t,:)=Sx(i,:);
    uxt(t+1,:) = 1-(Sxt(t,:)>0).*((1-s)*(1-uxt(t,:))+phi*uxt(t,:));   
end

sel=burn+1:T+burn;
yt=yt(sel);
uxt=uxt(sel,:);
Sxt=Sxt(sel,:);
ut=uxt*l;


% layoff rate
% Sxt=f_Sx(Ft);
sxt=(1-(Sxt>0)*(1-s)).*(1-uxt);
st=(sxt*l)./(1-ut);

% exit rate from unemployment
f0xt=(Sxt>0).*uxt;
f0t=(f0xt*l)*phi./ut;

% quit rate
f1xt=(Sxt>0).*(1-uxt);
f1t=(f1xt*l)*phi*(1-s)*tau*k./(1-ut);

% employment
ext=repmat(l',T,1).*(1-uxt);
et=squeeze(sum(ext,2));
ex=mean(ext);

% match productivity
pt=yt*(B*x+C)';
xt=sum(pt.*ext,2)./et;

% leisure cost
zxt=z0+alpha*(pt-z0);
zt=sum(zxt.*ext,2)./et;

%% output
X=[xt ut st f0t];

Me = mean(X);
Sd = std(log(X));
kurt = kurtosis(log(X));
Co = corr(log(X));
elas_x = Co(1,:).*Sd/Sd(1); % elastity wrt aggregate match productivity
rhox = regress(log(xt(2:T)),[ones(T-1,1) log(xt(1:T-1))]);

b1=[ Me(1); Sd(1); rhox(2); Me(2); Sd(2); kurt(2); Me(4)];
% b0=[ 1; .024; .91;  0.057;  0.22; 2.65 ; 0.78];

db=(b1-b0)./b0;
crit=db'*db;

