clear;
close all;


%% Initialisation

N=150;
M=500;

r=0.05/4; % discount rate 5pct annual
alpha = 0.6
tau=.5
k=0.12

logit=@(x) 1/(1+exp(x));

% nu =    2.006
% mu =    5.39
% s =    0.043
% phi =    .924
% rho =    0.95
% sig =    0.0265
% z0 =    0.773
% C =     0.748
% B=1.

% mu = nu*(B+C-1)/(1-C)
% C=1-B*nu/(nu+mu)


load x0;
b=x0;
nu=exp(b(1))
mu=exp(b(2))
s=logit(b(3))
phi=logit(b(4))
rho=tanh(b(5))
sig=exp(b(6))
z0=exp(b(7))
C=exp(b(8))
B=1

% C=.744
% z0=.775

%% DATA

dta = importdata('/Users/jeanmarc.robin/Documents/RECHERCHE/macrodyn/stata/work/USquarterly.raw');% BLS data
dta=dta(isnan(dta(:,1))==0,:);
dta=dta(isnan(dta(:,4))==0,:);
% b=regress(dta(:,1),[ones(length(dta(:,1)),1) dta(:,2)]);
% prod=b(1)+dta(:,2)*b(2);
prod=dta(:,1);
prod=prod/mean(prod);
T=length(prod);
wage=dta(:,2); 
unr=dta(:,3);
vac=dta(:,4);
tightness=dta(:,5);
f_q=dta(:,6);
s_q=dta(:,7);
year=dta(:,8);
qtr=dta(:,9);
% time=[int2str(year) repmat('Q',T,1) int2str(qtr)];
time=year+qtr/4;

%% output

disp('')
disp('     prod       wage       unr     f_q        s_q       vac     tightness');
X=[prod(1:T-1) wage(1:T-1) unr(2:T) f_q(1:T-1) s_q(1:T-1) vac(1:T-1) tightness(1:T-1)];


Me=mean(X)
Sd=std(log(X))
Co=corr(log(X))
skew=skewness(log(X))
kurt=kurtosis(log(X))
elas_x=Co(1,:).*Sd/Sd(1)  % elasity wrt aggregate match productivity
elas_u=Co(3,:).*Sd/Sd(3)  % elasticity wrt unemployment

disp('reg log(x_t) on log(x_t-1)')
regress(log(prod(2:T)),[ones(T-1,1) log(prod(1:T-1))])
disp('reg log(w_t) on log(w_t-1)')
regress(log(wage(2:T)),[ones(T-1,1) log(wage(1:T-1))])
disp('reg log(u_t) on log(u_t-1)')
regress(log(unr(2:T)),[ones(T-1,1) log(unr(1:T-1))])
disp('reg log(f_t) on log(f_t-1)')
regress(log(f_q(2:T)),[ones(T-1,1) log(f_q(1:T-1))])
disp('reg log(s_t) on log(s_t-1)')
regress(log(s_q(2:T)),[ones(T-1,1) log(s_q(1:T-1))])

disp('reg log(f_q) on log(\theta_t)')
[b bint]=regress(log(f_q(1:T-1)),[ones(T-1,1) log(tightness(1:T-1))])



disp('reg log(st) on log(ut)')
[b bint]=regress(log(s_q),[ones(T,1) log(unr)])
disp('reg log(f0t) on log(ut)')
[b bint]=regress(log(f_q),[ones(T,1) log(unr)])


% random numbers for innovations
T=length(prod);
% R = (norminv(normcdf(log(prod(2:end)),0,sig))...
%     -rho*norminv(normcdf(log(prod(1:end-1)),0,sig)))/sqrt(1-rho^2);
% draw=normcdf([0;R]);
[rho,rhostd,R]=regress(log(prod(2:end)),log(prod(1:end-1)));
sigu=std(R);
draw=normcdf([0;R],0,sigu);



%% GRIDS


% grid for abilities
trim=.002;
x=linspace(trim,1-trim,M)';
l=betapdf(x,nu,mu);
l=l/sum(l);


% grid for productivity
F = linspace(trim,1-trim,N)';
y = exp(sig*norminv(F));
% fy = normpdf(log(y),0,sig)./y; fy=fy/sum(fy);
[U1,U2] = meshgrid(F); 
P = copulapdf('Gaussian',[U1(:) U2(:)],rho); 
P = reshape(P,N,N);
Pi = P./repmat(sum(P,2),1,N);

% match productivity
p=y*(B*x+C)';


% unemployment payoff
z=z0+alpha*(p-z0);




%% Unemployment value and surplus

beta=(1-s)/(1+r);

% p and z are NxM matrices 
% U and S also

Ux = (eye(N)-Pi/(1+r))\z;
Sx = (eye(N)-beta*Pi)\(p-z);
e = norm(Sx-max(Sx,0),'fro');

while e>0.00001
    Sx1 = Sx;
    Sx = p-z + beta*Pi*max(Sx,0);
    e=norm(Sx-Sx1,'fro');
end

S = max(Sx,0)*l; % aggregate surplus
L = (Sx>0)*l;

%% Steady-state

ux = (s/(s+phi))*(Sx>0)+(Sx<=0);
u = 1-phi.*L./(s+phi);



%% Dynamics

burn = 0;
T1= burn+T;
uxt = ones(T1+1,M);
Ft=ones(T1,1);
yt=ones(T1,1);
statet=zeros(T1,1);

%initial condition
i = min(sum(y-prod(1)<=0),N);
Ft(1) = F(i);
yt(1)= y(i);
statet(1) = i;
uxt(1,:) = ux(i,:);


res=zeros(T,2);

if burn>0
    draw = [rand(burn,1);draw];
end

for t=1:(burn+T)
    
    % find prod innovation
    uxt_1 = 1-(Sx>0).*...
        repmat((1-s)*(1-uxt(t,:))+phi*uxt(t,:),N,1);
    ext = repmat(l',N,1).*(1-uxt_1);
    et = sum(ext,2);
    xt = sum(p.*ext,2)./et;
    [ysort,i] = sort(abs(xt-prod(t)));
    i = i(1);
    statet(t) = i;
    yt(t) = y(i);
  
    % unemployment
    uxt(t+1,:)=1-(Sx(i,:)>0).*...
        ((1-s)*(1-uxt(t,:))+phi*uxt(t,:));
    


end


sel=(burn+1):(burn+T);
statet=statet(sel);
Ft=Ft(sel);
yt=yt(sel);

uxt=uxt(sel,:);

ut=uxt*l;


c=mean(phi*max(Sx(i,:),0)*l)/mean(vac)
theta=s*phi*S./(s+(1-L+k*(1-s)*L)*phi)/c;
v=theta.*(u+k*(1-s)*(1-u));

% layoff rate
Sxt=Sx(statet,:);
ft=phi*ones(T,1);
vt=phi/c*max(Sxt,0)*l;
thetat=vt./(ut+k*(1-s)*(1-ut));

sxt=(1-(Sxt>0)*(1-s)).*(1-uxt);
st=(sxt*l)./(1-ut);

% exit rate from unemployment
f0xt=(Sxt>0).*uxt;
f0t=(f0xt*l)*phi./ut;

% quit rate
f1xt=(Sxt>0).*(1-uxt);
f1t=(f1xt*l)*phi*(1-s)*tau*k./(1-ut);

% employment
ext=repmat(l',T,1).*(1-uxt);
et=squeeze(sum(ext,2));
ex=mean(ext);

% match productivity
pt=yt*(B*x+C)';
xt=sum(pt.*ext,2)./et;

% leisure cost
zxt=z0+alpha*(pt-z0);
zt=sum(zxt.*ext,2)./et;
mean(zt./xt)

tetat=vt./ut;

%% output

disp('')
disp('     yt       xt        ut        f0t        st       f1t       vt     thetat ');
X=[yt(1:T-1) xt(1:T-1) ut(2:T) f0t(1:T-1) st(1:T-1) f1t(1:T-1) vt(1:T-1) thetat(1:T-1) ];


Me=mean(X)
Sd=std(log(X))
Co=corr(log(X))
skew=skewness(log(X))
kurt=kurtosis(log(X))
elas_x=Co(2,:).*Sd/Sd(2)  % elasity wrt aggregate match productivity
elas_u=Co(3,:).*Sd/Sd(3); % elasticity wrt unemployment

disp('reg log(y_t) on log(y_t-1)')
regress(log(yt(2:T)),[ones(T-1,1) log(yt(1:T-1))])
disp('reg log(x_t) on log(x_t-1)')
regress(log(xt(2:T)),[ones(T-1,1) log(xt(1:T-1))])
disp('reg log(u_t) on log(u_t-1)')
regress(log(ut(2:T)),[ones(T-1,1) log(ut(1:T-1))])
disp('reg log(f_t) on log(f_t-1)')
regress(log(f0t(2:T)),[ones(T-1,1) log(f0t(1:T-1))])
disp('reg log(s_t) on log(s_t-1)')
regress(log(st(2:T)),[ones(T-1,1) log(st(1:T-1))])


disp('reg log(f0t) on log(\theta_t)')
[b bint]=regress(log(f0t(1:T-1)),[ones(T-1,1) log(thetat(1:T-1))])



disp('reg log(st) on log(ut)')
[b bint]=regress(log(st),[ones(T,1) log(ut)])
lstpred=[ones(T,1) log(ut)]*b;
disp('reg log(f0t) on log(ut)')
[b bint]=regress(log(f0t),[ones(T,1) log(ut)])
lf0tpred=[ones(T,1) log(ut)]*b;
disp('reg log(f1t) on log(ut)')
[b bint]=regress(log(f1t),[ones(T,1) log(ut)])
lf1tpred=[ones(T,1) log(ut)]*b;



%% Figures

figure(1)

minp=y;
for i=1:N
    minp(i)=min(p(i,Sx(i,:)>0));
end

plot(y,minp,'r','LineWidth',2)

hold on
plot(y,y,'LineWidth',2)
plot(y,p(:,(1:10:M)),'--','LineWidth',1)
xlabel('Aggregate shock')
ylabel('Match productivity')
legend('viability threshold', 'aggregate shock','productivity by type'...
    ,'Location','NorthWest')
hold off
axis tight
% saveas(gcf,'figures/prodbytype.eps','epsc');

figure(2)
wFb=ones(N,1);
plot(B*x+C,((wFb'*ux)'.*l)./(wFb'*ux*l),'-.',...
    B*x+C,l,'r','LineWidth',2)
axis tight
xlabel('ability')
grid on
legend('Unemployed','All' ,'Location','NorthEast')
% saveas(gcf,'figures/hetero_dist.eps','epsc');

figure(31)
plot(time,prod,'r--',time,xt,time, yt,'black-.','LineWidth',1)
legend('actual productivity','predicted','aggregate shock')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fitprod.eps','epsc');

[r1,r2,r3,r4,r5]=regress(prod, [ones(T,1) xt]);
disp('predict prod'); r5(1)

figure(32)
plot(time,unr,'r--',time,ut,'LineWidth',1)
% plot(unr,ut,'LineWidth',1)
legend('actual unemployment rate','predicted')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fitunr.eps','epsc');

[r1,r2,r3,r4,r5]=regress(unr, [ones(T,1) ut]);
disp('predict unemp'); r5(1)
T1=156;
[r1,r2,r3,r4,r5]=regress(unr(1:T1), [ones(T1,1) ut(1:T1)]);
disp(['predict unemp 1:',num2str(T1)]); r5(1)

% T1=T;
% T0=156;
% % [r1,r2,r3,r4,r5]=regress(unr(T0:T1), [ones(T1-T0+1,1) ut(T0:T1) ut(T0-1:T1-1) ut(T0-2:T1-2) ut(T0-3:T1-3)]);
% [r1,r2,r3,r4,r5]=regress(unr(T0:T1), [ones(T1-T0+1,1)  ut(T0-8:T1-8)]);
% disp(['predict unemp 1:',num2str(T1)]); r5(1)


figure(33)
plot(time,f_q,'r--',time,f0t,'LineWidth',1)
legend('actual unemployment exit rate','predicted')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fitf0.eps','epsc');

[r1,r2,r3,r4,r5]=regress(f_q, [ones(T,1) f0t]);
disp('predict jfr'); r5(1)
[r1,r2,r3,r4,r5]=regress(f_q(1:T1), [ones(T1,1) f0t(1:T1)]);
disp(['predict jfr 1:',num2str(T1)]); r5(1)

figure(34)
plot(time,s_q,'r--',time,st,'LineWidth',1)
legend('actual job destruction rate','predicted')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fits.eps','epsc');


[r1,r2,r3,r4,r5]=regress(s_q, [ones(T,1) st]);
disp('predict ldr'); r5(1)
[r1,r2,r3,r4,r5]=regress(s_q(1:T1), [ones(T1,1) st(1:T1)]);
disp(['predict ldr 1:',num2str(T1)]); r5(1)
[r1,r2,r3,r4,r5]=regress(s_q(3:T), [ones(T-2,1) st(3:T)+st(2:T-1)+st(1:T-2)]);
disp('predict ldr'); r5(1)

figure(35)
plot(time,tightness,'r--',time,thetat,'LineWidth',1)
legend('actual tightness','predicted')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fittightness.eps','epsc');


[r1,r2,r3,r4,r5]=regress(tightness, [ones(T,1) thetat]);
disp('predict tight'); r5(1)
[r1,r2,r3,r4,r5]=regress(tightness(1:T1), [ones(T1,1) thetat(1:T1)]);
disp(['predict tight 1:',num2str(T1)]); r5(1)

figure(36)
plot(time,vac,'r--',time,vt,'LineWidth',1)
legend('actual vacancies','predicted','Location','Southwest')
xlabel('time')
xlim([time(1)-5 time(end)+5])
% saveas(gcf,'figures/fitvacancies.eps','epsc');


[r1,r2,r3,r4,r5]=regress(vac, [ones(T,1) vt]);
disp('predict vac'); r5(1)
[r1,r2,r3,r4,r5]=regress(vac(1:T1), [ones(T1,1) vt(1:T1)]);
disp(['predict vac 1:',num2str(T1)]); r5(1)


figure(4)
[xtsort,xtind]=sort(xt);
% plot(xt(xtind),zt(xtind)./xt(xtind))
zx=mean(zxt./pt);
plot(B*x+C,zx,B*x+C,mean(zx),'LineWidth',1)
xlabel('ability')
ylabel('mean leisure cost')
set(gca,'YTick',[min(zx) mean(zx) max(zx)])
% saveas(gcf,'figures/z.eps','epsc');



figure(5)
plot(yt,ut,'*')
ylabel('unemployment rate')
xlabel('aggregate shock')
hold on
% figure(6)
plot(y,u,'r','LineWidth',2)
hold off
% saveas(gcf,'figures/amplification.eps','epsc');


figure(7)
plot(log(thetat),log(f0t),'.',log(tightness),log(f_q),'ro')
xlabel('log tightness')
ylabel('log unemployment exit rate')
legend('predicted','actual')

% figure(8)
% plot(ut,uxt(:,1:5)*l(1:5)/sum(l(1:5)),'b',...
%     ut,uxt(:,6:10)*l(6:10)/sum(l(6:10)),'r',...
%     ut,uxt(:,11:15)*l(11:15)/sum(l(11:15)),'g',...
%     ut,uxt(:,16:20)*l(16:20)/sum(l(16:20)),'black')
% xlabel('overall unemployment rate')
% legend('1-5','6-10','11-15','16-20')

figure(8)
[us,iu]=sort(u);
uxs=ux(iu,:);
nn=[75;113;235];
plot(us,uxs(:,1:nn(1))*l(1:nn(1))/sum(l(1:nn(1))),'b-',...
    us,uxs(:,1:nn(2))*l(1:nn(2))/sum(l(1:nn(2))),'r--',...
    us,uxs(:,1:nn(3))*l(1:nn(3))/sum(l(1:nn(3))),'black-.',...  
    'Linewidth',2)
xlabel('overall unemployment rate')
legend([int2str(sum(l(1:nn(1))*100)) '% low'],...
    [int2str(sum(l(1:nn(2))*100)) '% low'],...
    [int2str(sum(l(1:nn(3))*100)) '% low'],...
    'Location','Northwest')   
% saveas(gcf,'figures/unemp_compo.eps','epsc');


