/********************************************************************
Calculate wage inequality dynamics and elasticities wrt productivity 
********************************************************************/

* aggregate collapse USquarterly at yearly freq.
clear
use "USquarterly"
collapse lph_c lp_c lp lph, by(year)
save "productivity_work_y", replace


* get earnings percentiles from Jonathan Heathcote and Fabrizio Perri and Giovanni L. Violante, 
* Unequal We Stand: An Empirical Analysis of Economic Inequality in the United States: 1967-2006, 
* Review of Economic Dynamics (2010), pp. 15-51
* http://www.EconomicDynamics.org/codes/09/09-214/USA_CPS_programs.zip

clear

insheet using "raw_data/individ_pctiles_work_hrs_wage.csv"

rename true_year year

merge 1:1 year using "productivity_work_y", keep(match)
drop _merge

tsset year, yearly
g t = _n

local reg="lph_c"
reg `reg' t
predict reg, resid

local lmale="avg_wage_100male avg_wage_90male avg_wage_80male avg_wage_70male avg_wage_60male avg_wage_50male avg_wage_40male avg_wage_30male avg_wage_20male avg_wage_10male"
local lfemale="avg_wage_100female avg_wage_90female avg_wage_80female avg_wage_70female avg_wage_60female avg_wage_50female avg_wage_40female avg_wage_30female avg_wage_20female avg_wage_10female"
local lall="avg_wage_100 avg_wage_90 avg_wage_80 avg_wage_70 avg_wage_60 avg_wage_50 avg_wage_40 avg_wage_30 avg_wage_20 avg_wage_10"

su `lmale' `lfemale' `lall'	
	
foreach var in `lmale' `lfemale' `lall' {
	g l`var'=log(`var')
	qui reg l`var' t 
	predict u`var',res
	qui su l`var'
	replace u`var'=u`var'+r(mean)
	gen p`var'=exp(u`var')
	su u`var'
	regress u`var' reg
	}

/*
local lmale="avg_hrs_100male avg_hrs_90male avg_hrs_80male avg_hrs_70male avg_hrs_60male avg_hrs_50male avg_hrs_40male avg_hrs_30male avg_hrs_20male avg_hrs_10male"
local lfemale="avg_hrs_100female avg_hrs_90female avg_hrs_80female avg_hrs_70female avg_hrs_60female avg_hrs_50female avg_hrs_40female avg_hrs_30female avg_hrs_20female avg_hrs_10female"
local lall="avg_hrs_100 avg_hrs_90 avg_hrs_80 avg_hrs_70 avg_hrs_60 avg_hrs_50 avg_hrs_40 avg_hrs_30 avg_hrs_20 avg_hrs_10"

su `lmale' `lfemale' `lall'	
	
foreach var in `lmale' `lfemale' `lall' {
	g l`var'=log(`var')
	regress l`var' year lph
	qui regress l`var' year
	predict u`var',res
	}
*/


tsline avg_wage_90 avg_wage_80 avg_wage_70 avg_wage_60 avg_wage_50 avg_wage_40 avg_wage_30 avg_wage_20 avg_wage_10,/*
   */ legend(off) 
   
tsline pavg_wage_90 pavg_wage_80 pavg_wage_70 pavg_wage_60 pavg_wage_50 pavg_wage_40 pavg_wage_30 pavg_wage_20 pavg_wage_10,/*
   */ legend(off) ytitle(detrended wage deciles)
gr export "figures/wagedeciles.eps", replace

* line `lall' `reg', sort
