/*******************************************************************

Merge CPS and JOLTS rates with vacancies (help-wanted index)
Extrapolate HW index using JOLTS Job Openings

*******************************************************************/


clear

* Help-wanted index
use "raw_data/help_raw_m"
drop Month
g time=ym(year,month)

* merge with unemployment rates
merge 1:1 time using "jolts_unemployment_work_m"
tsset time, monthly
drop _merge


********************************************
* Fill in help-wanted ad index after 2003
********************************************	

tw (tsline J if time>=ym(2000,12)) (tsline V if time>=ym(2000,12), yaxis(2))
gr export "figures/J_V_m.eps", replace

regress V J if time<ym(2003,1)
cap drop Vhat
predict Vhat
tsline V Vhat, legend(label(2 "job openings (JOLTS)"))
gr export "figures/help_jobOpenings_m.eps", replace

g v=V if time<ym(2003,1)
replace v=Vhat if time>=ym(2003,1)
su v if time>=ym(2000,12)
replace v=v/r(mean)
su J if time>=ym(2000,12)
replace v=v*r(mean)
replace v=v/(U+E)
label var v "vacancies"
tsline v
gr export "figures/vacancies_m.eps", replace

save "jolts_unemployment_help_work_m", replace


**************************
* log term relationships
**************************

sc F.ur v, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("vacancies")
gr export "figures/ur_v_m.eps", replace

sc F.ur f, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("unemployment exit rate")
gr export "figures/ur_f_m.eps", replace

sc F.ur s, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("job destruction rate")
gr export "figures/ur_s_m.eps", replace

g theta=v/U
sc f theta, c(l)  ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("tightness")
gr export "figures/f_theta_m.eps", replace

sc F.ur theta, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("tightness")
gr export "figures/ur_theta_m.eps", replace

g urpred=L.s/(L.s+L.f)
sc ur urpred urpred, legend(off) ms(Oh i) c(i l) /*
	*/ ytitle("unemployment rate") xtitle("steady-state unemp. rate")
gr export "figures/ur_urpred_m.eps", replace



