/********************************************************
Aggregate monthly employment data at quarterly frequency
*********************************************************/


clear
use "jolts_unemployment_help_work_m"

* quarterly aggregation
recode month 1/3=1 4/6=2 7/9=3 10/12=4, gen(qtr)

* aggregate rates
g sq=F2.s+(1-F2.f-F2.s)*(F.s+(1-F.f-F.s)*s)
g fq=1-(1-f-s)*(1-F.f-F.s)*(1-F2.f-F2.s)-sq

g s5q=F2.s5+(1-F2.f5-F2.s5)*(F.s5+(1-F.f5-F.s5)*s5)
g f5q=1-(1-f5-s5)*(1-F.f5-F.s5)*(1-F2.f5-F2.s5)-s5q

keep if month==1|month==4|month==7|month==10
replace time=yq(year,qtr)
tsset time, quarterly
keep year qtr time ur fq sq f5q s5q U E v
rename fq f
rename sq s
rename f5q f5
rename s5q s5

label var ur "unemployment rate"
label var f "unemployment exit rate"
label var s "job destruction rate"

tsline ur
gr export "figures/ur_q.eps", replace
tsline f f5
gr export "figures/f_q.eps", replace
tsline s s5
gr export "figures/s_q.eps", replace

save "jolts_unemployment_help_work_q", replace

* test that aggregation works
g ub=(1-f)*ur+s*(1-ur)
su ur F.ur ub f s
tsline F.ur ub

g u5b=(1-f5)*ur+s5*(1-ur)
su ur F.ur u5b f5 s5
tsline F.ur u5b

**************************
* log term relationships
**************************

sc F.ur v, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("vacancies")
gr export "figures/ur_v_q.eps", replace

sc F.ur f, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("unemployment exit rate")
gr export "figures/ur_f_q.eps", replace

sc F.ur s, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("job destruction rate")
gr export "figures/ur_s_q.eps", replace

g theta=v/ur
sc f theta, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment exit rate") xtitle("tightness")
gr export "figures/f_theta_q.eps", replace

sc F.ur theta, c(l) mlabel(time) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("tightness")
gr export "figures/ur_theta_q.eps", replace

g urpred=L.s/(L.s+L.f)
sc ur urpred urpred, legend(off) ms(Oh i) c(i l) /*
	*/ ytitle("unemployment rate") xtitle("steady-state unemp. rate")
gr export "figures/ur_urpred_q.eps", replace

