/******************************************************************************
Compares CPS and JOLTS
*******************************************************************************/

*****************
*  get JOLTS data
*****************
clear
use "raw_data/jolts_raw_m"

g month=1 if Month=="M01"
replace month=2 if Month=="M02"
replace month=3 if Month=="M03"
replace month=4 if Month=="M04"
replace month=5 if Month=="M05"
replace month=6 if Month=="M06"
replace month=7 if Month=="M07"
replace month=8 if Month=="M08"
replace month=9 if Month=="M09"
replace month=10 if Month=="M10"
replace month=11 if Month=="M11"
replace month=12 if Month=="M12"

g time=ym(year,month)

****************
* merge with CPS
*****************
merge 1:1 time using "unemployment_work_m"
drop _merge

sort time
tsset time, monthly


g jfr=(H-Q)/U
g qur=Q/E
g ldr=(S-Q)/E
lab var jfr  "unemp. exit rate (JOLTS)" 
lab var qur  "quit rate (JOLTS)"
lab var ldr "job destr. rate (JOLTS)"
label var J "job openings (JOLTS)"


***********************
* compare jfr and qur
***********************

tw (tsline jfr, lpattern(_-)) (tsline qur, yaxis(2)) if time>=ym(2000,12)
gr export "figures/jfr_qur_m.eps", replace


save "jolts_unemployment_work_m",replace



/**********************************
* shows how JOLTS compares to CPS
**********************************/

tsline f jfr, legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))/*
	*/ lpattern(-- l) lcolor(blue red blue red) 
gr export "figures/f_jfr_m_all.eps", replace

tsline f jfr if time>=ym(2000,12), lcolor(blue red blue red) /*
	*/ lpattern(-- l ) legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))
gr export "figures/f_jfr_m.eps", replace

tsline s ldr, legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))/*
	*/ lpattern(-- l)   lcolor(blue red blue red) 
gr export "figures/s_ldr_m_all.eps", replace

tsline s ldr if time>=ym(2000,12), lcolor(blue red) /*
	*/ lpattern(-- l) legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))
gr export "figures/s_ldr_m.eps", replace

g dU_JOLTS = ldr*E-jfr*U
g dU_CPS=F.U-U

tsline dU_CPS dU_JOLTS, legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))/*
	*/ lpattern(-- l)  lcolor(blue red blue red) 
gr export "figures/predUnempChange_all.eps",replace

tsline dU_CPS dU_JOLTS if time>=ym(2000,12), legend(order (1 2) label(1 "CPS, flows") label(2 "JOLTS"))/*
	*/ lpattern(-- l)  lcolor(blue red blue red) 
gr export "figures/predUnempChange.eps",replace
