/*************************************************************
Run HP filter on quarterly data and calculate moments to match
**************************************************************/

clear

*********************************
* get quarterly productivity data
*********************************  
use "raw_data/productivity_raw_q"

g qtr=1 if Qtr=="Q01"
replace qtr=2 if Qtr=="Q02"
replace qtr=3 if Qtr=="Q03"
replace qtr=4 if Qtr=="Q04"

drop if Qtr=="Q05"

g time=yq(year,qtr)
tsset time, quarterly

save "productivity_work_q", replace

merge 1:1 time using "jolts_unemployment_help_work_q"
drop _merge

tsset time, quarterly

rename pp p

g ph=p*e/h
g w=wh/price*100*h/e
label var w "compensation per person"

g theta=v/(ur+.12*(1-ur))
label var theta "tightness"

pause on

foreach i of numlist 1e03 1e04 5e04 1e05 2.5e05 3e05 3.5e05 4e05 5e05 1e06 5e06 1e07 {
	di `i'
	g lp=log(p)
	hprescott lp, smooth(`i') stub("HP")	
	g lur=log(ur)
	hprescott lur, smooth(`i') stub("HP")
	corrgram HP_lp_1, lags(12)
	corr HP_lur_1 L.HP_lp_1 if year<=1990
	drop lp HP_lp_sm_1 HP_lp_1 lur HP_lur_sm_1 HP_lur_1
	}
	
local smooth=2.5e05    
local varlist "p w ur v theta f f5 s s5 ph"
local list=" "
foreach x of varlist `varlist' {
	g l`x'=log(`x')
	hprescott l`x', smooth(`smooth') stub("HP")
	rename HP_l`x'_1 l`x'_c
	rename HP_l`x'_sm_1 l`x'_t
	su l`x'_c
	local sdl`x'_c=r(sd)
	di "relative sd = " r(sd)/`sdlp_c'
	reg l`x'_c L.l`x'_c
	reg l`x'_c lp_c 
	*tw (line lp_c time) (line l`x'_c time, yaxis(2))
	*pause
	local list="`list'"+"l`x'_c "
	}
		
corr `list'
su `list'

hprescott lur, smooth(1600) stub("HP")
label var HP_lur_sm_1 "1600"
label var lur_t "`smooth'"
tw (tsline lur_t) (tsline HP_lur_sm_1,lpattern("-")) (tsline lur)
gr export "figures/ur_HP_different_freq.eps", replace       


local varlist "p w ur v theta f f5 s s5 ph"
foreach x of varlist `varlist' {
	su `x'
	local meanx=r(mean)
	local maxx=r(max)
	local minx=r(min)
	cap drop `x'_c `x'_t
	g `x'_c=exp(l`x'_c)*`meanx'
	g `x'_t=exp(l`x'_t)             
	label var `x'_c "detrended `x'"
	tsline `x'_c `x'_t `x', yline(`meanx') ylab(`meanx' `minx' `maxx')  /*
		*/ legend(label(1 "cycle") label(2 "trend")) lpattern(l _- --)
	graph export "figures/det`x'.eps",replace
	*pause
}

g time2=yq(year,qtr)
replace time2=.  if year<=2008
format time2 %tq
sc ur_c v_c, c(l) mlabel(time2) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("vacancies")
gr export "figures/det_ur_v.eps", replace

sc F.ur_c f_c, c(l) mlabel(time2) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("unemployment exit rate")
gr export "figures/det_ur_f.eps", replace

sc F.ur_c s_c, c(l) mlabel(time2) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment rate") xtitle("job destruction rate")
gr export "figures/det_ur_s.eps", replace

sc f_c theta_c, c(l) mlabel(time2) ms(Oh)  xsc(log) ysc(log)/*
	*/ ytitle("unemployment exit rate") xtitle("tightness")
gr export "figures/det_ur_theta.eps", replace

reg lf_c ltheta_c
reg lf5_c ltheta_c

save "USquarterly", replace
outfile p_c w_c ur_c v_c theta_c f_c s_c year qtr using "USquarterly", /*
	*/ replace nolabel comma
/*outfile p_c time using prod, replace nolabel
outfile w_c time using wage, replace nolabel
outfile ur_c time using ur, replace nolabel
outfile theta_c time using tightness, replace nolabel
outfile jfr_c time using f_q, replace nolabel
*/
