/**************************************************************************************
	Calculates monthly employment rates from CPS unemployment data obtained from BLS

***************************************************************************************/


clear
use "raw_data/unemployment_raw_m"

g month=1 if Month=="M01"
replace month=2 if Month=="M02"
replace month=3 if Month=="M03"
replace month=4 if Month=="M04"
replace month=5 if Month=="M05"
replace month=6 if Month=="M06"
replace month=7 if Month=="M07"
replace month=8 if Month=="M08"
replace month=9 if Month=="M09"
replace month=10 if Month=="M10"
replace month=11 if Month=="M11"
replace month=12 if Month=="M12"

g time=ym(year,month)
tsset time, monthly

replace ur=ur/100

* calculates rates from flows
g s=F.U5/E
g f=1-(F.U-F.U5)/U

* a different way of estimating f by matching moments of the distribution
* of unemployment durations
g U5p=U5_14+U15p
g f5=-4*log(U5p/U)/5
g f15=-4*log(U15p/U)/15
g f27=-4*log(U27p/U)/27

g s5=(F.U-(1-f5)*U)/E

label var ur "unemployment rate (CPS)"
label var f "unemp. exit rate (CPS; flows)"
label var s "layoff rate (CPS; flows)"
label var f5 "unemp. exit rate (CPS; > 5 weeks unemp.)"
label var s5 "layoff rate (CPS; > 5 weeks unemp.)"

save "unemployment_work_m", replace


************************************************************
*  compare different measures of exit rate from unemployment
************************************************************

/*
foreach x of varlist f f5 f15 f27 { 
	cap drop HP_`x'_1 
	cap drop HP_`x'_sm_1
	hprescott `x', smooth(1) stub("HP")
	*tsline `x' HP_`x'_sm_1, saving(`x'_m,replace) legend(off)
	*gr export `x'_m.eps, replace
	}
	
tsline HP_f5_sm_1 HP_f15_sm_1 HP_f27_sm_1 HP_f_sm_1, lpattern(_ _- -- l) /*
    */ lpattern(_ _- -- l) /*
	*/ legend(label(1 "more than 5 weeks unemployed") /*
	*/ label(2 "more than 15 weeks") label(3 "more than 27 weeks") label(4 "from flows") )
*/

tsline f5 f15 f27, legend(rows(3) label(1 "top line: more than 5 weeks unemployment") /*
	*/ label(2 "middle line: more than 15 weeks") label(3 "lower line: more than 27 weeks"))
gr export "figures/f5_f15_f27.eps", replace 

tsline f5 f,/*
	*/ legend(label(1 "more than 5 weeks unemployed") label(2 "from flows")) 
gr export "figures/f_f5.eps", replace 

tsline s5 s,/*
	*/ legend(label(1 "more than 5 weeks unemployed") label(2 "from flows")) 
gr export "figures/s_s5.eps", replace 

su f
g urpred_s=s/(s+r(mean))
tsline ur urpred_s
reg ur urpred_s

su s
g urpred_f=1-f/(f+r(mean))
tsline ur urpred_f
reg ur urpred_f

